@@ -15,21 +15,21 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 17
-#define ARROW_VERSION_MINOR 0
+#define ARROW_VERSION_MAJOR 18
+#define ARROW_VERSION_MINOR 1
 #define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "17.0.0"
+#define ARROW_VERSION_STRING "18.1.0"
 
-#define ARROW_SO_VERSION "1700"
-#define ARROW_FULL_SO_VERSION "1700.0.0"
+#define ARROW_SO_VERSION "1801"
+#define ARROW_FULL_SO_VERSION "1801.0.0"
 
-#define ARROW_CXX_COMPILER_ID "Clang"
-#define ARROW_CXX_COMPILER_VERSION "18.1.8"
-#define ARROW_CXX_COMPILER_FLAGS " -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -g -ffile-prefix-map=/build/arrow/src=/usr/src/debug/arrow -flto=auto -Qunused-arguments -fcolor-diagnostics  -Wall -Wno-unknown-warning-option -Wno-pass-failed -msse4.2 "
+#define ARROW_CXX_COMPILER_ID "GNU"
+#define ARROW_CXX_COMPILER_VERSION "14.2.1"
+#define ARROW_CXX_COMPILER_FLAGS " -Wredundant-move -Wno-noexcept-type -Wno-self-move -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -g -ffile-prefix-map=/build/arrow/src=/usr/src/debug/arrow -flto=auto -fdiagnostics-color=always  -Wall -Wno-conversion -Wno-sign-conversion -Wdate-time -Wimplicit-fallthrough -Wunused-result -fno-semantic-interposition "
 
-#define ARROW_BUILD_TYPE "RELEASE"
+#define ARROW_BUILD_TYPE "RELWITHDEBINFO"
 
 #define ARROW_PACKAGE_KIND ""
 
